Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(922)

Unified Diff: chrome/browser/profiles/profile_io_data.h

Issue 2458093003: Add DCHECKs to validate ProfileIOData's list of protocols.
Patch Set: Merge remote-tracking branch 'origin/master' into detect_unregistered_schemes Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/net/chrome_url_request_context_getter.cc ('k') | chrome/browser/profiles/profile_io_data.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/profiles/profile_io_data.h
diff --git a/chrome/browser/profiles/profile_io_data.h b/chrome/browser/profiles/profile_io_data.h
index 33e601110bfa689928c91619d20e22d1bc33f7ba..dfd5c5be43e59635f3d67464d4b6f2cd88666257 100644
--- a/chrome/browser/profiles/profile_io_data.h
+++ b/chrome/browser/profiles/profile_io_data.h
@@ -110,13 +110,13 @@ class ProfileIOData {
static ProfileIOData* FromResourceContext(content::ResourceContext* rc);
- // Returns true if |scheme| is handled in Chrome, or by default handlers in
- // net::URLRequest.
- static bool IsHandledProtocol(const std::string& scheme);
+ // Returns true if |scheme| is handled by a protocol handler built into in
+ // Chrome, or by default handlers in net::URLRequest.
+ static bool IsBuiltInProtocol(const std::string& scheme);
// Returns true if |url| is handled in Chrome, or by default handlers in
// net::URLRequest.
- static bool IsHandledURL(const GURL& url);
+ static bool HasBuiltInProtocol(const GURL& url);
// Utility to install additional WebUI handlers into the |job_factory|.
// Ownership of the handlers is transfered from |protocol_handlers|
« no previous file with comments | « chrome/browser/net/chrome_url_request_context_getter.cc ('k') | chrome/browser/profiles/profile_io_data.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698